# -*- coding: utf-8 -*-
"""package info"""

title = 'flaskcode'

version_info = (0, 0, 8)
version = '.'.join(map(str, version_info))

license = 'MIT'
copyright = 'Copyright (c) 2019 Sujeet Kumar <sujeetkv90@gmail.com>'

author = 'Sujeet Kumar'
email = 'sujeetkv90@gmail.com'
uri = 'https://github.com/sujeetkv/flaskcode'

description = 'Web based code editor on python flask framework'

status = 'Development'
